v1.2.2 - 2025-05-28
===================

Reverted astropy back to optional "wcs" group and changed the version from from 5.6.0 to 5.3.0 as 5.6 is not a real release of astropy

v1.2.1 - 2025-03-12
===================

Maintenance release, no changes otherwise

v1.2.0 - 2024-07-23
===================

Other Changes
~~~~~~~~~~~~~

- remove old circleci webhook config by @Cadair in
  https://github.com/sunpy/mpl-animators/pull/36
- Added Gallery + Update Package template by @nabobalis in
  https://github.com/sunpy/mpl-animators/pull/37
- Speed up CI by using different images per build by @Cadair in
  https://github.com/sunpy/mpl-animators/pull/39
- More circle jobs and trying to fix py39 upload by @Cadair in
  https://github.com/sunpy/mpl-animators/pull/40
- use sh not bash because nixos lol by @Cadair in
  https://github.com/sunpy/mpl-animators/pull/41
- Update website by @dstansby in
  https://github.com/sunpy/mpl-animators/pull/45
- gallery plus api docs by @nabobalis in
  https://github.com/sunpy/mpl-animators/pull/47
- Registers package to sunpy template by @CyclingNinja in
  https://github.com/sunpy/mpl-animators/pull/48
- Updates from the package template by @github-actions in
  https://github.com/sunpy/mpl-animators/pull/51
- Wrong base python for image upload by @nabobalis in
  https://github.com/sunpy/mpl-animators/pull/50
- Updates from the package template by @github-actions in
  https://github.com/sunpy/mpl-animators/pull/52
- Updates from the package template by @github-actions in
  https://github.com/sunpy/mpl-animators/pull/53

New Contributors
~~~~~~~~~~~~~~~~

- @dstansby made their first contribution in
  https://github.com/sunpy/mpl-animators/pull/45
- @CyclingNinja made their first contribution in
  https://github.com/sunpy/mpl-animators/pull/48
- @github-actions made their first contribution in
  https://github.com/sunpy/mpl-animators/pull/51

v1.1.2 - 2024-02-07
===================

Other Changes
~~~~~~~~~~~~~

-  remove old circleci webhook config by @Cadair in https://github.com/sunpy/mpl-animators/pull/36
-  Added Gallery + Update Package template by @nabobalis in https://github.com/sunpy/mpl-animators/pull/37

v1.1.1 - 2023-11-17
===================

Other Changes
~~~~~~~~~~~~~

-  Update for tox4 by @ConorMacBride in https://github.com/sunpy/mpl-animators/pull/20
-  Minor tweaks to CI - No actions by @nabobalis in https://github.com/sunpy/mpl-animators/pull/28
-  Move to actions by @nabobalis in https://github.com/sunpy/mpl-animators/pull/29
-  Bump stefanzweifel/git-auto-commit-action from 4 to 5 by @dependabot in https://github.com/sunpy/mpl-animators/pull/30
-  Bump actions/checkout from 2 to 4 by @dependabot in https://github.com/sunpy/mpl-animators/pull/31

New Contributors
----------------

-  @ConorMacBride made their first contribution in https://github.com/sunpy/mpl-animators/pull/20
-  @nabobalis made their first contribution in https://github.com/sunpy/mpl-animators/pull/28
-  @dependabot made their first contribution in https://github.com/sunpy/mpl-animators/pull/30

v1.1.0 - 2022-08-10
===================

Bug Fixes
~~~~~~~~~

-  Fix setting y limits when data is a dask array by SolarDrew in https://github.com/sunpy/mpl-animators/pull/11

Other Changes
~~~~~~~~~~~~~

-  Add changelog config and bump minimum Python version to 3.8 by Cadair in https://github.com/sunpy/mpl-animators/pull/12

New Contributors
~~~~~~~~~~~~~~~~

-  @SolarDrew made their first contribution in https://github.com/sunpy/mpl-animators/pull/11

v1.0.0
======

Initial release with code copied from ``sunpy.visualisation.animators``.
